@@ -41,10 +41,15 @@ build_container() {
   )
   buildah run $build_cntr dnf config-manager setopt '*-openh264.enabled=0'
   buildah run $build_cntr dnf install -y "${extra_packages[@]}"
+  buildah run $build_cntr dnf builddep malcontent -y # for building libmalcontent
   buildah run $build_cntr dnf debuginfo-install -y "${debug_packages[@]}"
   buildah run $build_cntr dnf clean all
   buildah run $build_cntr rm -rf /var/lib/cache/dnf
 
+  # somehow the sysusers trigger from the flatpak package messes up the
+  # permissions of /etc/passwd to be only readable by root
+  buildah run $build_cntr chmod 644 /etc/passwd
+
   # disable gnome-keyring activation:
   # it either asks for unlocking the login keyring on startup, or it detects
   # the running host daemon and doesn't export the object on the bus, which
@@ -54,6 +59,9 @@ build_container() {
   local srcdir=$(realpath $(dirname $0))
   buildah copy --chmod 755 $build_cntr $srcdir/install-meson-project.sh /usr/libexec
 
+  # add latest malcontent to the toolbox image for testing future integration
+  buildah run $build_cntr /usr/libexec/install-meson-project.sh https://gitlab.freedesktop.org/pwithnall/malcontent.git main -Dlibgsystemservice:gtk_doc=false
+
   # include convenience script for updating mutter dependency
   local update_mutter=$(mktemp)
   cat > $update_mutter <<-EOF
@@ -96,4 +104,6 @@ podman login -u $CI_REGISTRY_USER -p $CI_REGISTRY_PASSWORD $CI_REGISTRY
 
 build_container
 
-podman push $TOOLBOX_IMAGE
+if [[ -z "$DRY_RUN" ]]; then
+  podman push $TOOLBOX_IMAGE
+fi
