@@ -2,6 +2,7 @@
 
 srcdirs="src subprojects/extensions-tool"
 uidirs="js subprojects/extensions-app"
+desktopdirs="data subprojects/extensions-app/ subprojects/extensions-tool"
 
 # find source files that contain gettext keywords
 files=$(grep -lR --include='*.c' '\(gettext\|[^I_)]_\)(' $srcdirs)
@@ -9,6 +10,9 @@ files=$(grep -lR --include='*.c' '\(gettext\|[^I_)]_\)(' $srcdirs)
 # find ui files that contain translatable string
 files="$files "$(grep -lRi --include='*.ui' 'translatable="[ty1]' $uidirs)
 
+# find .desktop files
+files="$files "$(find $desktopdirs -name '*.desktop*')
+
 # filter out excluded files
 if [ -f po/POTFILES.skip ]; then
   files=$(for f in $files; do ! grep -q ^$f po/POTFILES.skip && echo $f; done)
