@@ -4,16 +4,16 @@ import Gio from 'gi://Gio';
 export {loadInterfaceXML} from './dbusUtils.js';
 
 /**
- * @typedef {object} SubdirInfo
- * @property {Gio.File} dir the file object for the subdir
- * @property {Gio.FileInfo} info the file descriptor for the subdir
+ * @typedef {object} ChildInfo
+ * @property {Gio.File} file the file object for the child
+ * @property {Gio.FileInfo} info the file descriptor for the child
  */
 
 /**
  * @param {string} subdir the subdirectory to search within the data directories
  * @param {boolean} includeUserDir whether the user's data directory should also be searched in addition
  *                                 to the system data directories
- * @returns {Generator<SubdirInfo, void, void>} a generator which yields file info for subdirectories named
+ * @returns {Generator<ChildInfo, void, void>} a generator which yields child infos for subdirectories named
  *                                              `subdir` within data directories
  */
 export function* collectFromDatadirs(subdir, includeUserDir) {
@@ -35,7 +35,7 @@ export function* collectFromDatadirs(subdir, includeUserDir) {
         if (fileEnum != null) {
             let info;
             while ((info = fileEnum.next_file(null)))
-                yield {dir: fileEnum.get_child(info), info};
+                yield {file: fileEnum.get_child(info), info};
         }
     }
 }
