@@ -26,7 +26,6 @@ import * as Main from './main.js';
 
 import * as Config from '../misc/config.js';
 
-const MENU_POPUP_TIMEOUT = 600;
 const POPDOWN_DIALOG_TIMEOUT = 500;
 
 const FOLDER_SUBICON_FRACTION = .4;
@@ -470,12 +469,6 @@ class BaseAppViewGridLayout extends Clutter.BinLayout {
 
 var BaseAppView = GObject.registerClass({
     GTypeFlags: GObject.TypeFlags.ABSTRACT,
-    Properties: {
-        'gesture-modes': GObject.ParamSpec.flags(
-            'gesture-modes', null, null,
-            GObject.ParamFlags.READWRITE | GObject.ParamFlags.CONSTRUCT_ONLY,
-            Shell.ActionMode, Shell.ActionMode.OVERVIEW),
-    },
     Signals: {
         'view-loaded': {},
     },
@@ -607,7 +600,11 @@ var BaseAppView = GObject.registerClass({
 
         // Swipe
         this._swipeTracker = new SwipeTracker.SwipeTracker(this._scrollView,
-            Clutter.Orientation.HORIZONTAL, this.gestureModes);
+            Clutter.Orientation.HORIZONTAL,
+            Shell.ActionMode.ALL,
+            {
+                name: 'AppDisplay swipe tracker',
+            });
         this._swipeTracker.orientation = Clutter.Orientation.HORIZONTAL;
         this._swipeTracker.connect('begin', this._swipeBegin.bind(this));
         this._swipeTracker.connect('update', this._swipeUpdate.bind(this));
@@ -708,11 +705,6 @@ var BaseAppView = GObject.registerClass({
         if (monitor !== Main.layoutManager.primaryIndex)
             return;
 
-        if (this._dragFocus) {
-            this._dragFocus.cancelActions();
-            this._dragFocus = null;
-        }
-
         const adjustment = this._adjustment;
         adjustment.remove_transition('value');
 
@@ -935,8 +927,6 @@ var BaseAppView = GObject.registerClass({
         };
         DND.addDragMonitor(this._dragMonitor);
         this._appGridLayout.showPageIndicators();
-        this._dragFocus = null;
-        this._swipeTracker.enabled = false;
     }
 
     _onDragMotion(dragEvent) {
@@ -984,7 +974,6 @@ var BaseAppView = GObject.registerClass({
         this._resetDragPageSwitch();
 
         this._appGridLayout.hidePageIndicators();
-        this._swipeTracker.enabled = true;
     }
 
     _onDragCancelled() {
@@ -992,7 +981,6 @@ var BaseAppView = GObject.registerClass({
         // will move all items to their original positions
         this._redisplay();
         this._appGridLayout.hidePageIndicators();
-        this._swipeTracker.enabled = true;
     }
 
     _canAccept(source) {
@@ -1262,10 +1250,6 @@ var BaseAppView = GObject.registerClass({
         this._appGridLayout.goToPage(pageNumber, animate);
         this._grid.goToPage(pageNumber, animate);
     }
-
-    updateDragFocus(dragFocus) {
-        this._dragFocus = dragFocus;
-    }
 });
 
 const PageManager = GObject.registerClass({
@@ -1457,10 +1441,6 @@ class AppDisplay extends BaseAppView {
             global.settings.is_writable('app-picker-layout');
 
         this._placeholder = new AppIcon(app, {isDraggable});
-        this._placeholder.connect('notify::pressed', icon => {
-            if (icon.pressed)
-                this.updateDragFocus(icon);
-        });
         this._placeholder.scaleAndFade();
         this._redisplay();
     }
@@ -1536,10 +1516,6 @@ class AppDisplay extends BaseAppView {
                     this._redisplay();
                     this._savePages();
                 });
-                icon.connect('notify::pressed', () => {
-                    if (icon.pressed)
-                        this.updateDragFocus(icon);
-                });
             }
 
             // Don't try to display empty folders
@@ -1573,10 +1549,6 @@ class AppDisplay extends BaseAppView {
                 let app = appSys.lookup_app(appId);
 
                 icon = new AppIcon(app, {isDraggable});
-                icon.connect('notify::pressed', () => {
-                    if (icon.pressed)
-                        this.updateDragFocus(icon);
-                });
             }
 
             appIcons.push(icon);
@@ -1886,10 +1858,11 @@ class AppViewItem extends St.Button {
 
         if (isDraggable) {
             this._draggable = DND.makeDraggable(this, {timeoutThreshold: 200});
-
-            this._draggable.connect('drag-begin', this._onDragBegin.bind(this));
-            this._draggable.connect('drag-cancelled', this._onDragCancelled.bind(this));
-            this._draggable.connect('drag-end', this._onDragEnd.bind(this));
+            this._draggable.connectObject(
+                'drag-begin', this._onDragBegin.bind(this),
+                'drag-cancelled', this._onDragCancelled.bind(this),
+                'drag-end', this._onDragEnd.bind(this),
+                this);
         }
 
         this._otherIconIsHovering = false;
@@ -2065,12 +2038,6 @@ class AppViewItem extends St.Button {
         return true;
     }
 
-    cancelActions() {
-        if (this._draggable)
-            this._draggable.fakeRelease();
-        this.fake_release();
-    }
-
     get id() {
         return this._id;
     }
@@ -2115,7 +2082,6 @@ class FolderView extends BaseAppView {
             layout_manager: new Clutter.BinLayout(),
             x_expand: true,
             y_expand: true,
-            gesture_modes: Shell.ActionMode.POPUP,
         });
 
         // If it not expand, the parent doesn't take into account its preferred_width when allocating
@@ -2494,16 +2460,14 @@ export const AppFolderDialog = GObject.registerClass({
 
         this.add_constraint(new Layout.MonitorConstraint({primary: true}));
 
-        const clickAction = new Clutter.ClickAction();
-        clickAction.connect('clicked', () => {
-            const [x, y] = clickAction.get_coords();
-            const actor =
-                global.stage.get_actor_at_pos(Clutter.PickMode.ALL, x, y);
-
-            if (!this._viewBox.contains(actor))
-                this.popdown();
+        const clickGesture = new Clutter.ClickGesture();
+        clickGesture.connect('may-recognize', () => {
+            const coords = clickGesture.get_coords_abs();
+            const [, x, y] = this.child.transform_stage_point(coords.x, coords.y);
+            return !this._viewBox.allocation.contains(x, y);
         });
-        this.add_action(clickAction);
+        clickGesture.connect('recognize', () => this.popdown());
+        this.add_action(clickGesture);
 
         this._source = source;
         this._folder = folder;
@@ -2699,7 +2663,7 @@ export const AppFolderDialog = GObject.registerClass({
             scale_y: 1,
             opacity: 255,
             duration: FOLDER_DIALOG_ANIMATION_TIME,
-            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+            mode: Clutter.AnimationMode.EASE_OUT_EXPO,
         });
 
         this._needsZoomAndFade = false;
@@ -2730,14 +2694,19 @@ export const AppFolderDialog = GObject.registerClass({
             mode: Clutter.AnimationMode.EASE_OUT_QUAD,
         });
 
+        this.child.ease({
+            opacity: 0,
+            duration: FOLDER_DIALOG_ANIMATION_TIME,
+            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+        });
+
         this.child.ease({
             translation_x: sourceX - dialogX,
             translation_y: sourceY - dialogY,
             scale_x: this._source.width / this.child.width,
             scale_y: this._source.height / this.child.height,
-            opacity: 0,
             duration: FOLDER_DIALOG_ANIMATION_TIME,
-            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
+            mode: Clutter.AnimationMode.EASE_OUT_EXPO,
             onComplete: () => {
                 this.child.set({
                     translation_x: 0,
@@ -2934,9 +2903,11 @@ export const AppIcon = GObject.registerClass({
     },
 }, class AppIcon extends AppViewItem {
     _init(app, iconParams = {}) {
-        // Get the isDraggable property without passing it on to the BaseIcon:
+        // Get properties without passing them on to the BaseIcon:
         const isDraggable = iconParams['isDraggable'] ?? true;
         delete iconParams['isDraggable'];
+        const popupMenuSide = iconParams['popupMenuSide'] ?? St.Side.LEFT;
+        delete iconParams['popupMenuSide'];
         const expandTitleOnHover = iconParams['expandTitleOnHover'];
         delete iconParams['expandTitleOnHover'];
 
@@ -2945,6 +2916,7 @@ export const AppIcon = GObject.registerClass({
         this.app = app;
         this._id = app.get_id();
         this._name = app.get_name();
+        this._popupMenuSide = popupMenuSide;
 
         this._iconContainer = new St.Widget({
             layout_manager: new Clutter.BinLayout(),
@@ -2979,10 +2951,20 @@ export const AppIcon = GObject.registerClass({
         this._menu = null;
         this._menuManager = new PopupMenu.PopupMenuManager(this);
 
-        this._menuTimeoutId = 0;
         this.app.connectObject('notify::state',
             () => this._updateRunningStyle(), this);
         this._updateRunningStyle();
+
+        const longPressGesture = new Clutter.LongPressGesture();
+        longPressGesture.connect('recognize', () => this.popupMenu());
+        this.add_action(longPressGesture);
+
+        const rightClickGesture = new Clutter.ClickGesture({
+            required_button: Clutter.BUTTON_SECONDARY,
+            recognize_on_press: true,
+        });
+        rightClickGesture.connect('recognize', () => this.popupMenu());
+        this.add_action(rightClickGesture);
     }
 
     _onDestroy() {
@@ -2992,28 +2974,12 @@ export const AppIcon = GObject.registerClass({
             GLib.source_remove(this._folderPreviewId);
             this._folderPreviewId = 0;
         }
-
-        this._removeMenuTimeout();
-    }
-
-    _onDragBegin() {
-        if (this._menu)
-            this._menu.close(true);
-        this._removeMenuTimeout();
-        super._onDragBegin();
     }
 
     _createIcon(iconSize) {
         return this.app.create_icon_texture(iconSize);
     }
 
-    _removeMenuTimeout() {
-        if (this._menuTimeoutId > 0) {
-            GLib.source_remove(this._menuTimeoutId);
-            this._menuTimeoutId = 0;
-        }
-    }
-
     _updateDotStyle() {
         const themeNode = this._dot.get_theme_node();
         this._dot.translationY = themeNode.get_length('offset-y');
@@ -3026,46 +2992,7 @@ export const AppIcon = GObject.registerClass({
             this._dot.hide();
     }
 
-    _setPopupTimeout() {
-        this._removeMenuTimeout();
-        this._menuTimeoutId = GLib.timeout_add(GLib.PRIORITY_DEFAULT, MENU_POPUP_TIMEOUT, () => {
-            this._menuTimeoutId = 0;
-            this.popupMenu();
-            return GLib.SOURCE_REMOVE;
-        });
-        GLib.Source.set_name_by_id(this._menuTimeoutId, '[gnome-shell] this.popupMenu');
-    }
-
-    vfunc_leave_event(event) {
-        const ret = super.vfunc_leave_event(event);
-
-        this.fake_release();
-        this._removeMenuTimeout();
-        return ret;
-    }
-
-    vfunc_button_press_event(event) {
-        const ret = super.vfunc_button_press_event(event);
-        const button = event.get_button();
-        if (button === 1) {
-            this._setPopupTimeout();
-        } else if (button === 3) {
-            this.popupMenu();
-            return Clutter.EVENT_STOP;
-        }
-        return ret;
-    }
-
-    vfunc_touch_event(event) {
-        const ret = super.vfunc_touch_event(event);
-        if (event.type() === Clutter.EventType.TOUCH_BEGIN)
-            this._setPopupTimeout();
-
-        return ret;
-    }
-
     vfunc_clicked(button) {
-        this._removeMenuTimeout();
         this.activate(button);
     }
 
@@ -3078,13 +3005,11 @@ export const AppIcon = GObject.registerClass({
         return this.app.get_id();
     }
 
-    popupMenu(side = St.Side.LEFT) {
+    popupMenu() {
         this.setForcedHighlight(true);
-        this._removeMenuTimeout();
-        this.fake_release();
 
         if (!this._menu) {
-            this._menu = new AppMenu(this, side, {
+            this._menu = new AppMenu(this, this._popupMenuSide, {
                 favoritesSection: true,
                 showSingleWindows: true,
             });
@@ -3217,13 +3142,6 @@ export const AppIcon = GObject.registerClass({
 
         return view?.createFolder(apps);
     }
-
-    cancelActions() {
-        if (this._menu)
-            this._menu.close(true);
-        this._removeMenuTimeout();
-        super.cancelActions();
-    }
 });
 
 const SystemActionIcon = GObject.registerClass(
