@@ -175,8 +175,8 @@ export class AppMenu extends PopupMenu.PopupMenu {
 
         const launchGpu = this._getNonDefaultLaunchGpu();
         this._onGpuMenuItem.label.text = launchGpu === Shell.AppLaunchGpu.DEFAULT
-            ? _('Launch using Integrated Graphics Card')
-            : _('Launch using Discrete Graphics Card');
+            ? _('Launch Using Integrated Graphics Card')
+            : _('Launch Using Discrete Graphics Card');
     }
 
     _updateDetailsVisibility() {
