@@ -264,7 +264,7 @@ class ShowAppsIcon extends DashItemContainer {
         const laters = global.compositor.get_laters();
         laters.add(Meta.LaterType.BEFORE_REDRAW, () => {
             AppFavorites.getAppFavorites().removeFavorite(id);
-            return false;
+            return GLib.SOURCE_REMOVE;
         });
 
         return true;
@@ -821,7 +821,17 @@ export const Dash = GObject.registerClass({
                 });
                 this._box.add_child(this._separator);
             }
-            let pos = nFavorites + this._animatingPlaceholdersCount;
+            let pos = nFavorites;
+            let itemsBeforeSeparator = 0;
+            for (const item of this._box.get_children()) {
+                if (item.animatingOut)
+                    pos++;
+                itemsBeforeSeparator++;
+                // Assuming only one icon is moved at a time
+                // Or else we need to track removed favorite items
+                if (itemsBeforeSeparator > nFavorites)
+                    break;
+            }
             if (this._dragPlaceholder)
                 pos++;
             this._box.set_child_at_index(this._separator, pos);
@@ -978,7 +988,7 @@ export const Dash = GObject.registerClass({
                 appFavorites.moveFavoriteToPos(id, favPos);
             else
                 appFavorites.addFavoriteAtPos(id, favPos);
-            return false;
+            return GLib.SOURCE_REMOVE;
         });
 
         return true;
