@@ -158,6 +158,10 @@ export const QuickMenuToggle = GObject.registerClass({
             'menu-enabled', null, null,
             GObject.ParamFlags.READWRITE,
             true),
+        'menu-button-accessible-name': GObject.ParamSpec.string(
+            'menu-button-accessible-name', null, null,
+            GObject.ParamFlags.READWRITE,
+            _('Open menu')),
     },
 }, class QuickMenuToggle extends QuickSettingsItem {
     _init(params) {
@@ -182,7 +186,6 @@ export const QuickMenuToggle = GObject.registerClass({
         this._menuButton = new St.Button({
             style_class: 'quick-toggle-menu-button icon-button',
             child: new St.Icon({icon_name: 'go-next-symbolic'}),
-            accessible_name: _('Open menu'),
             can_focus: true,
             x_expand: false,
             y_expand: true,
@@ -216,6 +219,9 @@ export const QuickMenuToggle = GObject.registerClass({
         this.bind_property('menu-enabled',
             this._menuButton, 'visible',
             GObject.BindingFlags.SYNC_CREATE);
+        this.bind_property('menu-button-accessible-name',
+            this._menuButton, 'accessible-name',
+            GObject.BindingFlags.SYNC_CREATE);
         this.bind_property('reactive',
             this._menuButton, 'reactive',
             GObject.BindingFlags.SYNC_CREATE);
@@ -251,6 +257,10 @@ export const QuickSlider = GObject.registerClass({
             'menu-enabled', null, null,
             GObject.ParamFlags.READWRITE,
             false),
+        'menu-button-accessible-name': GObject.ParamSpec.string(
+            'menu-button-accessible-name', null, null,
+            GObject.ParamFlags.READWRITE,
+            _('Open menu')),
     },
     Signals: {
         'icon-clicked': {},
@@ -337,10 +347,12 @@ export const QuickSlider = GObject.registerClass({
             can_focus: true,
             x_expand: false,
             y_expand: true,
-            accessible_name: _('Open menu'),
         });
         box.add_child(this._menuButton);
 
+        this.bind_property('menu-button-accessible-name',
+            this._menuButton, 'accessible-name',
+            GObject.BindingFlags.SYNC_CREATE);
         this.bind_property('menu-enabled',
             this._menuButton, 'visible',
             GObject.BindingFlags.SYNC_CREATE);
@@ -835,7 +847,7 @@ export const QuickSettingsMenu = class extends PopupMenu.PopupMenu {
         });
 
         this._boxPointer.ease_property('@effects.dim.brightness', color, {
-            mode: Clutter.AnimationMode.LINEAR,
+            mode: Clutter.AnimationMode.EASE_OUT_QUAD,
             duration: POPUP_ANIMATION_TIME,
             onStopped: () => (this._dimEffect.enabled = dim),
         });
