@@ -50,13 +50,6 @@ class BrightnessItem extends QuickSlider {
 
         this._manager = Main.brightnessManager;
         this._manager.connectObject('changed',
-            this._onManagerChanged.bind(this), this);
-        this._onManagerChanged();
-    }
-
-    _onManagerChanged() {
-        this._manager.globalScale?.disconnectObject(this);
-        this._manager.globalScale?.connectObject('notify::locked',
             this._sync.bind(this), this);
         this._sync();
     }
@@ -64,7 +57,7 @@ class BrightnessItem extends QuickSlider {
     _sync() {
         const {globalScale} = this._manager;
         this.set({
-            visible: globalScale && !globalScale.locked,
+            visible: globalScale,
             menuEnabled: this._manager.scales.length > 1,
         });
 
