@@ -31,12 +31,20 @@ const PROFILE_PARAMS = {
     },
 };
 
+const FALLBACK_PARAMS = {
+    name: C_('Power profile', 'Custom'),
+    iconName: 'gnome-power-manager-symbolic',
+};
+
 const LAST_PROFILE_KEY = 'last-selected-power-profile';
 
 const PowerProfilesToggle = GObject.registerClass(
 class PowerProfilesToggle extends QuickMenuToggle {
     _init() {
-        super._init({title: _('Power Mode')});
+        super._init({
+            title: _('Power Mode'),
+            menuButtonAccessibleName: _('Open power profiles menu'),
+        });
 
         this._profileItems = new Map();
 
@@ -82,6 +90,9 @@ class PowerProfilesToggle extends QuickMenuToggle {
             .map(p => p.Profile.unpack())
             .reverse();
         for (const profile of profiles) {
+            if (!PROFILE_PARAMS[profile])
+                continue;
+
             const {name, iconName} = PROFILE_PARAMS[profile];
             if (!name)
                 continue;
@@ -110,7 +121,7 @@ class PowerProfilesToggle extends QuickMenuToggle {
                 : PopupMenu.Ornament.NONE);
         }
 
-        const {name: subtitle, iconName} = PROFILE_PARAMS[activeProfile];
+        const {name: subtitle, iconName} = PROFILE_PARAMS[activeProfile] ?? FALLBACK_PARAMS;
         this.set({subtitle, iconName});
 
         this.checked = activeProfile !== 'balanced';
