@@ -108,20 +108,22 @@ export const WindowPreview = GObject.registerClass({
             dragActorMaxSize: WINDOW_DND_SIZE,
             dragActorOpacity: DRAGGING_WINDOW_OPACITY,
         });
-        this._draggable.connect('drag-begin', this._onDragBegin.bind(this));
-        this._draggable.connect('drag-cancelled', this._onDragCancelled.bind(this));
-        this._draggable.connect('drag-end', this._onDragEnd.bind(this));
+        this._draggable.connectObject(
+            'drag-begin', this._onDragBegin.bind(this),
+            'drag-cancelled', this._onDragCancelled.bind(this),
+            'drag-end', this._onDragEnd.bind(this),
+            this);
         this.inDrag = false;
 
-        let clickAction = new Clutter.ClickAction();
-        clickAction.connect('clicked', () => this._activate());
-        clickAction.connect('long-press', (action, actor, state) => {
-            if (state === Clutter.LongPressState.ACTIVATE)
-                this.showOverlay(true);
-            return true;
-        });
+        const clickGesture = new Clutter.ClickGesture();
+        clickGesture.connect('recognize', () => this._activate());
+        this.add_action(clickGesture);
 
-        this._draggable.addClickAction(clickAction);
+        const longPressGesture = new Clutter.LongPressGesture();
+        longPressGesture.connect('recognize', () => this.showOverlay(true));
+        this.add_action(longPressGesture);
+
+        longPressGesture.can_not_cancel(this._draggable.startGesture);
 
         this._overlayEnabled = true;
         this._overlayShown = false;
