@@ -1,11 +1,8 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-#ifndef SHELL_TRAY_ICON_PRIVATE_H
-#define SHELL_TRAY_ICON_PRIVATE_H
+#pragma once
 
 #include "shell-tray-icon.h"
 
 #include "na-tray-child.h"
 
 ClutterActor * shell_tray_icon_new (NaTrayChild *tray_child);
-
-#endif /* SHELL_TRAY_ICON_PRIVATE_H */
