@@ -1,8 +1,8 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-#ifndef __SHELL_WM_PRIVATE_H__
-#define __SHELL_WM_PRIVATE_H__
+#pragma once
 
 #include "shell-wm.h"
+#include <mtk/mtk.h>
 
 G_BEGIN_DECLS
 
@@ -17,8 +17,8 @@ void _shell_wm_size_changed(ShellWM         *wm,
 void _shell_wm_size_change(ShellWM         *wm,
                            MetaWindowActor *actor,
                            MetaSizeChange   which_change,
-                           MetaRectangle   *old_frame_rect,
-                           MetaRectangle   *old_buffer_rect);
+                           MtkRectangle    *old_frame_rect,
+                           MtkRectangle    *old_buffer_rect);
 void _shell_wm_map        (ShellWM         *wm,
                            MetaWindowActor *actor);
 void _shell_wm_destroy    (ShellWM         *wm,
@@ -34,7 +34,7 @@ void _shell_wm_kill_switch_workspace (ShellWM             *wm);
 
 void _shell_wm_show_tile_preview     (ShellWM             *wm,
                                       MetaWindow          *window,
-                                      MetaRectangle       *tile_rect,
+                                      MtkRectangle        *tile_rect,
                                       int                  tile_monitor);
 void _shell_wm_hide_tile_preview     (ShellWM             *wm);
 void _shell_wm_show_window_menu      (ShellWM             *wm,
@@ -45,7 +45,7 @@ void _shell_wm_show_window_menu      (ShellWM             *wm,
 void _shell_wm_show_window_menu_for_rect (ShellWM             *wm,
                                           MetaWindow          *window,
                                           MetaWindowMenuType   menu,
-                                          MetaRectangle       *rect);
+                                          MtkRectangle        *rect);
 
 gboolean _shell_wm_filter_keybinding (ShellWM             *wm,
                                       MetaKeyBinding      *binding);
@@ -59,5 +59,3 @@ MetaInhibitShortcutsDialog * _shell_wm_create_inhibit_shortcuts_dialog (ShellWM
                                                                         MetaWindow  *window);
 
 G_END_DECLS
-
-#endif /* __SHELL_WM_PRIVATE_H__ */
