@@ -58,8 +58,8 @@
 enum {
   PROP_0,
 
+  PROP_ORIENTATION,
   PROP_VERTICAL,
-  PROP_PACK_START,
 
   N_PROPS
 };
@@ -86,16 +86,17 @@ st_box_layout_get_property (GObject    *object,
 
   switch (property_id)
     {
+    case PROP_ORIENTATION:
+      layout = clutter_actor_get_layout_manager (CLUTTER_ACTOR (object));
+      orientation = clutter_box_layout_get_orientation (CLUTTER_BOX_LAYOUT (layout));
+      g_value_set_enum (value, orientation);
+      break;
     case PROP_VERTICAL:
       layout = clutter_actor_get_layout_manager (CLUTTER_ACTOR (object));
       orientation = clutter_box_layout_get_orientation (CLUTTER_BOX_LAYOUT (layout));
       g_value_set_boolean (value, orientation == CLUTTER_ORIENTATION_VERTICAL);
       break;
 
-    case PROP_PACK_START:
-      g_value_set_boolean (value, FALSE);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
     }
@@ -111,11 +112,13 @@ st_box_layout_set_property (GObject      *object,
 
   switch (property_id)
     {
-    case PROP_VERTICAL:
-      st_box_layout_set_vertical (box, g_value_get_boolean (value));
+    case PROP_ORIENTATION:
+      st_box_layout_set_orientation (box, g_value_get_enum (value));
       break;
-
-    case PROP_PACK_START:
+    case PROP_VERTICAL:
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+      st_box_layout_set_vertical (box, g_value_get_boolean (value));
+G_GNUC_END_IGNORE_DEPRECATIONS
       break;
 
     default:
@@ -144,6 +147,7 @@ on_layout_orientation_changed (GObject    *object,
                                gpointer    user_data)
 {
   GObject *box = user_data;
+  g_object_notify_by_pspec (box, props[PROP_ORIENTATION]);
   g_object_notify_by_pspec (box, props[PROP_VERTICAL]);
 }
 
@@ -174,6 +178,18 @@ st_box_layout_class_init (StBoxLayoutClass *klass)
 
   widget_class->style_changed = st_box_layout_style_changed;
 
+  /**
+   * StBoxLayout:orientation:
+   *
+   * The orientation of the #StBoxLayout, either horizontal or
+   * vertical
+   */
+  props[PROP_ORIENTATION] =
+    g_param_spec_enum ("orientation", NULL, NULL,
+                       CLUTTER_TYPE_ORIENTATION,
+                       CLUTTER_ORIENTATION_HORIZONTAL,
+                       ST_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
+
   /**
    * StBoxLayout:vertical:
    *
@@ -183,18 +199,7 @@ st_box_layout_class_init (StBoxLayoutClass *klass)
   props[PROP_VERTICAL] =
     g_param_spec_boolean ("vertical", NULL, NULL,
                           FALSE,
-                          ST_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY);
-
-  /**
-   * StBoxLayout:pack-start:
-   *
-   * A convenience property for the #ClutterBoxLayout:pack-start property of the
-   * internal layout for #StBoxLayout.
-   */
-  props[PROP_PACK_START] =
-    g_param_spec_boolean ("pack-start", NULL, NULL,
-                          FALSE,
-                          ST_PARAM_READWRITE | G_PARAM_DEPRECATED);
+                          ST_PARAM_READWRITE | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
 
   g_object_class_install_properties (object_class, N_PROPS, props);
 
@@ -223,6 +228,47 @@ st_box_layout_new (void)
   return g_object_new (ST_TYPE_BOX_LAYOUT, NULL);
 }
 
+/**
+ * st_box_layout_set_orientation:
+ * @box: A #StBoxLayout
+ * @orientation: the orientation of the #StBoxLayout
+ *
+ * Set the value of the #StBoxLayout:orientation property
+ */
+void
+st_box_layout_set_orientation (StBoxLayout        *box,
+                               ClutterOrientation  orientation)
+{
+  ClutterLayoutManager *layout;
+
+  g_return_if_fail (ST_IS_BOX_LAYOUT (box));
+
+  layout = clutter_actor_get_layout_manager (CLUTTER_ACTOR (box));
+
+  if (clutter_box_layout_get_orientation (CLUTTER_BOX_LAYOUT (layout)) != orientation)
+    clutter_box_layout_set_orientation (CLUTTER_BOX_LAYOUT (layout), orientation);
+}
+
+/**
+ * st_box_layout_get_orientation:
+ * @box: A #StBoxLayout
+ *
+ * Get the value of the #StBoxLayout:orientation property.
+ *
+ * Returns: the orientation
+ */
+ClutterOrientation
+st_box_layout_get_orientation (StBoxLayout *box)
+{
+  ClutterLayoutManager *layout;
+
+  g_return_val_if_fail (ST_IS_BOX_LAYOUT (box),
+                        CLUTTER_ORIENTATION_HORIZONTAL);
+
+  layout = clutter_actor_get_layout_manager (CLUTTER_ACTOR (box));
+  return clutter_box_layout_get_orientation (CLUTTER_BOX_LAYOUT (layout));
+}
+
 /**
  * st_box_layout_set_vertical:
  * @box: A #StBoxLayout
@@ -234,17 +280,13 @@ void
 st_box_layout_set_vertical (StBoxLayout *box,
                             gboolean     vertical)
 {
-  ClutterLayoutManager *layout;
   ClutterOrientation orientation;
 
   g_return_if_fail (ST_IS_BOX_LAYOUT (box));
 
-  layout = clutter_actor_get_layout_manager (CLUTTER_ACTOR (box));
   orientation = vertical ? CLUTTER_ORIENTATION_VERTICAL
                          : CLUTTER_ORIENTATION_HORIZONTAL;
-
-  if (clutter_box_layout_get_orientation (CLUTTER_BOX_LAYOUT (layout)) != orientation)
-    clutter_box_layout_set_orientation (CLUTTER_BOX_LAYOUT (layout), orientation);
+  st_box_layout_set_orientation (box, orientation);
 }
 
 /**
@@ -258,38 +300,10 @@ st_box_layout_set_vertical (StBoxLayout *box,
 gboolean
 st_box_layout_get_vertical (StBoxLayout *box)
 {
-  ClutterLayoutManager *layout;
   ClutterOrientation orientation;
 
   g_return_val_if_fail (ST_IS_BOX_LAYOUT (box), FALSE);
 
-  layout = clutter_actor_get_layout_manager (CLUTTER_ACTOR (box));
-  orientation = clutter_box_layout_get_orientation (CLUTTER_BOX_LAYOUT (layout));
+  orientation = st_box_layout_get_orientation (box);
   return orientation == CLUTTER_ORIENTATION_VERTICAL;
 }
-
-/**
- * st_box_layout_set_pack_start:
- * @box: A #StBoxLayout
- * @pack_start: %TRUE if the layout should use pack-start
- *
- * Deprecated: No longer has any effect
- */
-void
-st_box_layout_set_pack_start (StBoxLayout *box,
-                              gboolean     pack_start)
-{
-}
-
-/**
- * st_box_layout_get_pack_start:
- * @box: A #StBoxLayout
- *
- * Returns: the value of the #StBoxLayout:pack-start property,
- *   always %FALSE
- */
-gboolean
-st_box_layout_get_pack_start (StBoxLayout *box)
-{
-  return FALSE;
-}
